@@ -1,4 +1,3 @@
-/* $Id: pjmedia-codec.h 5630 2017-07-19 10:29:10Z riza $ */
 /* 
  * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
  * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
@@ -24,24 +23,26 @@
  * @file pjmedia-codec.h
  * @brief Include all codecs API in PJMEDIA-CODEC
  */
-
+#include <pjmedia-codec/and_aud_mediacodec.h>
+#include <pjmedia-codec/and_vid_mediacodec.h>
 #include <pjmedia-codec/audio_codecs.h>
-#include <pjmedia-codec/l16.h>
+#include <pjmedia-codec/bcg729.h>
 #include <pjmedia-codec/ffmpeg_vid_codecs.h>
-#include <pjmedia-codec/gsm.h>
-#include <pjmedia-codec/speex.h>
-#include <pjmedia-codec/ilbc.h>
 #include <pjmedia-codec/g722.h>
 #include <pjmedia-codec/g7221.h>
+#include <pjmedia-codec/gsm.h>
+#include <pjmedia-codec/ilbc.h>
 #include <pjmedia-codec/ipp_codecs.h>
+#include <pjmedia-codec/l16.h>
+#include <pjmedia-codec/lyra.h>
 #include <pjmedia-codec/opencore_amr.h>
-#include <pjmedia-codec/vid_toolbox.h>
 #include <pjmedia-codec/openh264.h>
+#include <pjmedia-codec/opus.h>
 #include <pjmedia-codec/passthrough.h>
 #include <pjmedia-codec/silk.h>
-#include <pjmedia-codec/opus.h>
-#include <pjmedia-codec/bcg729.h>
+#include <pjmedia-codec/speex.h>
+#include <pjmedia-codec/vid_toolbox.h>
+#include <pjmedia-codec/vpx.h>
 
-
-#endif	/* __PJMEDIA_CODEC_PJMEDIA_CODEC_H__ */
+#endif  /* __PJMEDIA_CODEC_PJMEDIA_CODEC_H__ */
 
