@@ -1,4 +1,3 @@
-/* $Id: sip_endpoint.h 5971 2019-04-23 08:42:45Z nanang $ */
 /* 
  * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
  * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
@@ -75,7 +74,7 @@ typedef void (*pjsip_endpt_exit_callback)(pjsip_endpoint *endpt);
  * future memory allocations by SIP components will be taken from the same
  * pool factory.
  *
- * @param pf	        Pool factory that will be used for the lifetime of 
+ * @param pf            Pool factory that will be used for the lifetime of 
  *                      endpoint.
  * @param name          Optional name to be specified for the endpoint.
  *                      If this parameter is NULL, then the name will use
@@ -85,7 +84,7 @@ typedef void (*pjsip_endpt_exit_callback)(pjsip_endpoint *endpt);
  * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_create(pj_pool_factory *pf,
-					const char *name,
+                                        const char *name,
                                         pjsip_endpoint **endpt);
 
 /**
@@ -93,7 +92,7 @@ PJ_DECL(pj_status_t) pjsip_endpt_create(pj_pool_factory *pf,
  * transactions have been terminated properly, because this function does not
  * check for the presence of pending transactions.
  *
- * @param endpt		The SIP endpoint to be destroyed.
+ * @param endpt         The SIP endpoint to be destroyed.
  */
 PJ_DECL(void) pjsip_endpt_destroy(pjsip_endpoint *endpt);
 
@@ -113,31 +112,31 @@ PJ_DECL(const pj_str_t*) pjsip_endpt_name(const pjsip_endpoint *endpt);
  * manner.  This function, like all other endpoint functions, is thread safe, 
  * and application may have more than one thread concurrently calling this function.
  *
- * @param endpt		The endpoint.
- * @param max_timeout	Maximum time to wait for events, or NULL to wait forever
- *			until event is received.
+ * @param endpt         The endpoint.
+ * @param max_timeout   Maximum time to wait for events, or NULL to wait forever
+ *                      until event is received.
  *
- * @return		PJ_SUCCESS on success.
+ * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_handle_events( pjsip_endpoint *endpt, 
-					        const pj_time_val *max_timeout);
+                                                const pj_time_val *max_timeout);
 
 
 /**
  * Handle events with additional info about number of events that
  * have been handled.
  *
- * @param endpt		The endpoint.
- * @param max_timeout	Maximum time to wait for events, or NULL to wait forever
- *			until event is received.
- * @param count		Optional argument to receive the number of events that
- *			have been handled by the function.
+ * @param endpt         The endpoint.
+ * @param max_timeout   Maximum time to wait for events, or NULL to wait forever
+ *                      until event is received.
+ * @param count         Optional argument to receive the number of events that
+ *                      have been handled by the function.
  *
- * @return		PJ_SUCCESS on success.
+ * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_handle_events2(pjsip_endpoint *endpt,
-					        const pj_time_val *max_timeout,
-					        unsigned *count);
+                                                const pj_time_val *max_timeout,
+                                                unsigned *count);
 
 /**
  * Schedule timer to endpoint's timer heap. Application must poll the endpoint
@@ -146,25 +145,25 @@ PJ_DECL(pj_status_t) pjsip_endpt_handle_events2(pjsip_endpoint *endpt,
  * has elapsed, the callback specified in the entry argument will be called.
  * This function, like all other endpoint functions, is thread safe.
  *
- * @param endpt	    The endpoint.
- * @param entry	    The timer entry.
- * @param delay	    The relative delay of the timer.
- * @return	    PJ_OK (zero) if successfull.
+ * @param endpt     The endpoint.
+ * @param entry     The timer entry.
+ * @param delay     The relative delay of the timer.
+ * @return          PJ_OK (zero) if successfull.
  */
 #if PJ_TIMER_DEBUG
 #define pjsip_endpt_schedule_timer(ept,ent,d) \
-			pjsip_endpt_schedule_timer_dbg(ept, ent, d, \
-			                               __FILE__, __LINE__)
+                        pjsip_endpt_schedule_timer_dbg(ept, ent, d, \
+                                                       __FILE__, __LINE__)
 
 PJ_DECL(pj_status_t) pjsip_endpt_schedule_timer_dbg(pjsip_endpoint *endpt,
-						    pj_timer_entry *entry,
-						    const pj_time_val *delay,
-						    const char *src_file,
-						    int src_line);
+                                                    pj_timer_entry *entry,
+                                                    const pj_time_val *delay,
+                                                    const char *src_file,
+                                                    int src_line);
 #else
 PJ_DECL(pj_status_t) pjsip_endpt_schedule_timer( pjsip_endpoint *endpt,
-						 pj_timer_entry *entry,
-						 const pj_time_val *delay );
+                                                 pj_timer_entry *entry,
+                                                 const pj_time_val *delay );
 #endif
 
 /**
@@ -175,52 +174,52 @@ PJ_DECL(pj_status_t) pjsip_endpt_schedule_timer( pjsip_endpoint *endpt,
  * argument will be called. This function, like all other endpoint functions,
  * is thread safe.
  *
- * @param endpt	    The endpoint.
- * @param entry	    The timer entry.
- * @param delay	    The relative delay of the timer.
+ * @param endpt     The endpoint.
+ * @param entry     The timer entry.
+ * @param delay     The relative delay of the timer.
  * @param id_val    The value to be set to the "id" field of the timer entry
- * 		    once the timer is scheduled.
+ *                  once the timer is scheduled.
  * @param grp_lock  The group lock.
- * @return	    PJ_OK (zero) if successfull.
+ * @return          PJ_OK (zero) if successfull.
  */
 #if PJ_TIMER_DEBUG
 #define pjsip_endpt_schedule_timer_w_grp_lock(ept,ent,d,id,gl) \
-		pjsip_endpt_schedule_timer_w_grp_lock_dbg(ept,ent,d,id,gl,\
-							  __FILE__, __LINE__)
+                pjsip_endpt_schedule_timer_w_grp_lock_dbg(ept,ent,d,id,gl,\
+                                                          __FILE__, __LINE__)
 
 PJ_DECL(pj_status_t) pjsip_endpt_schedule_timer_w_grp_lock_dbg(
-						    pjsip_endpoint *endpt,
-						    pj_timer_entry *entry,
-						    const pj_time_val *delay,
-						    int id_val,
-						    pj_grp_lock_t *grp_lock,
-						    const char *src_file,
-						    int src_line);
+                                                    pjsip_endpoint *endpt,
+                                                    pj_timer_entry *entry,
+                                                    const pj_time_val *delay,
+                                                    int id_val,
+                                                    pj_grp_lock_t *grp_lock,
+                                                    const char *src_file,
+                                                    int src_line);
 #else
 PJ_DECL(pj_status_t) pjsip_endpt_schedule_timer_w_grp_lock(
-						 pjsip_endpoint *endpt,
-						 pj_timer_entry *entry,
-						 const pj_time_val *delay,
-						 int id_val,
-						 pj_grp_lock_t *grp_lock );
+                                                 pjsip_endpoint *endpt,
+                                                 pj_timer_entry *entry,
+                                                 const pj_time_val *delay,
+                                                 int id_val,
+                                                 pj_grp_lock_t *grp_lock );
 #endif
 
 /**
  * Cancel the previously registered timer.
  * This function, like all other endpoint functions, is thread safe.
  *
- * @param endpt	    The endpoint.
- * @param entry	    The timer entry previously registered.
+ * @param endpt     The endpoint.
+ * @param entry     The timer entry previously registered.
  */
 PJ_DECL(void) pjsip_endpt_cancel_timer( pjsip_endpoint *endpt, 
-					pj_timer_entry *entry );
+                                        pj_timer_entry *entry );
 
 /**
  * Get the timer heap instance of the SIP endpoint.
  *
- * @param endpt	    The endpoint.
+ * @param endpt     The endpoint.
  *
- * @return	    The timer heap instance.
+ * @return          The timer heap instance.
  */
 PJ_DECL(pj_timer_heap_t*) pjsip_endpt_get_timer_heap(pjsip_endpoint *endpt);
 
@@ -231,26 +230,26 @@ PJ_DECL(pj_timer_heap_t*) pjsip_endpt_get_timer_heap(pjsip_endpoint *endpt);
  * properly initialize the module, and assign a unique module ID for the 
  * module.
  *
- * @param endpt		The endpoint.
- * @param module	The module to be registered.
+ * @param endpt         The endpoint.
+ * @param module        The module to be registered.
  *
- * @return		PJ_SUCCESS on success.
+ * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_register_module( pjsip_endpoint *endpt,
-						  pjsip_module *module );
+                                                  pjsip_module *module );
 
 /**
  * Unregister a module from the endpoint.
  * The endpoint will then call the stop and unload function in the module to 
  * properly shutdown the module.
  *
- * @param endpt		The endpoint.
- * @param module	The module to be registered.
+ * @param endpt         The endpoint.
+ * @param module        The module to be registered.
  *
- * @return		PJ_SUCCESS on success.
+ * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_unregister_module( pjsip_endpoint *endpt,
-						    pjsip_module *module );
+                                                    pjsip_module *module );
 
 /**
  * This describes additional parameters to pjsip_endpt_process_rx_data()
@@ -292,7 +291,7 @@ typedef struct pjsip_process_rdata_param
 /**
  * Initialize with default.
  *
- * @param p	The param.
+ * @param p     The param.
  */
 PJ_DECL(void) pjsip_process_rdata_param_default(pjsip_process_rdata_param *p);
 
@@ -309,15 +308,15 @@ PJ_DECL(void) pjsip_process_rdata_param_default(pjsip_process_rdata_param *p);
  * long operation, it resumes pjsip's module processing by calling this
  * function, and then free the cloned rdata.
  *
- * @param endpt		The endpoint instance.
- * @param rdata		The rdata to be distributed.
- * @param p		Optional pointer to param to specify from which module
- * 			the processing should start.
- * @param p_handled	Optional pointer to receive last return value of
- * 			module's \a on_rx_request() or \a on_rx_response()
- * 			callback.
+ * @param endpt         The endpoint instance.
+ * @param rdata         The rdata to be distributed.
+ * @param p             Optional pointer to param to specify from which module
+ *                      the processing should start.
+ * @param p_handled     Optional pointer to receive last return value of
+ *                      module's \a on_rx_request() or \a on_rx_response()
+ *                      callback.
  *
- * @return		PJ_SUCCESS on success.
+ * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_process_rx_data(pjsip_endpoint *endpt,
                                                  pjsip_rx_data *rdata,
@@ -330,73 +329,73 @@ PJ_DECL(pj_status_t) pjsip_endpt_process_rx_data(pjsip_endpoint *endpt,
  * allocated from the same pool factory. This function, like all other endpoint
  * functions, is thread safe.
  *
- * @param endpt		The SIP endpoint.
- * @param pool_name	Name to be assigned to the pool.
- * @param initial	The initial size of the pool.
- * @param increment	The resize size.
- * @return		Memory pool, or NULL on failure.
+ * @param endpt         The SIP endpoint.
+ * @param pool_name     Name to be assigned to the pool.
+ * @param initial       The initial size of the pool.
+ * @param increment     The resize size.
+ * @return              Memory pool, or NULL on failure.
  *
  * @see pj_pool_create
  */
 PJ_DECL(pj_pool_t*) pjsip_endpt_create_pool( pjsip_endpoint *endpt,
-					     const char *pool_name,
-					     pj_size_t initial,
-					     pj_size_t increment );
+                                             const char *pool_name,
+                                             pj_size_t initial,
+                                             pj_size_t increment );
 
 /**
  * Return back pool to endpoint to be released back to the pool factory.
  * This function, like all other endpoint functions, is thread safe.
  *
- * @param endpt	    The endpoint.
- * @param pool	    The pool to be destroyed.
+ * @param endpt     The endpoint.
+ * @param pool      The pool to be destroyed.
  */
 PJ_DECL(void) pjsip_endpt_release_pool( pjsip_endpoint *endpt,
-					pj_pool_t *pool );
+                                        pj_pool_t *pool );
 
 /**
  * Find transaction in endpoint's transaction table by the transaction's key.
  * This function normally is only used by modules. The key for a transaction
  * can be created by calling #pjsip_tsx_create_key.
  *
- * @param endpt	    The endpoint instance.
- * @param key	    Transaction key, as created with #pjsip_tsx_create_key.
+ * @param endpt     The endpoint instance.
+ * @param key       Transaction key, as created with #pjsip_tsx_create_key.
  *
- * @return	    The transaction, or NULL if it's not found.
+ * @return          The transaction, or NULL if it's not found.
  */
 PJ_DECL(pjsip_transaction*) pjsip_endpt_find_tsx( pjsip_endpoint *endpt,
-					          const pj_str_t *key );
+                                                  const pj_str_t *key );
 
 /**
  * Register the transaction to the endpoint's transaction table.
  * This function should only be used internally by the stack.
  *
- * @param endpt	    The SIP endpoint.
- * @param tsx	    The transaction.
+ * @param endpt     The SIP endpoint.
+ * @param tsx       The transaction.
  */
 PJ_DECL(void) pjsip_endpt_register_tsx( pjsip_endpoint *endpt,
-					pjsip_transaction *tsx);
+                                        pjsip_transaction *tsx);
 
 /**
  * Forcefull destroy the transaction. This function should only be used
  * internally by the stack.
  *
- * @param endpt	    The endpoint.
- * @param tsx	    The transaction to destroy.
+ * @param endpt     The endpoint.
+ * @param tsx       The transaction to destroy.
  */
 PJ_DECL(void) pjsip_endpt_destroy_tsx( pjsip_endpoint *endpt,
-				      pjsip_transaction *tsx);
+                                      pjsip_transaction *tsx);
 
 /**
  * Create a new transmit data buffer.
  * This function, like all other endpoint functions, is thread safe.
  *
- * @param endpt	    The endpoint.
+ * @param endpt     The endpoint.
  * @param p_tdata    Pointer to receive transmit data buffer.
  *
- * @return	    PJ_SUCCESS or the appropriate error code.
+ * @return          PJ_SUCCESS or the appropriate error code.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_create_tdata( pjsip_endpoint *endpt,
-					       pjsip_tx_data **p_tdata);
+                                               pjsip_tx_data **p_tdata);
 
 /**
  * Create the DNS resolver instance. Application creates the DNS
@@ -404,14 +403,14 @@ PJ_DECL(pj_status_t) pjsip_endpt_create_tdata( pjsip_endpoint *endpt,
  * resolver, then set the DNS resolver to be used by the endpoint
  * by calling #pjsip_endpt_set_resolver().
  *
- * @param endpt		The SIP endpoint instance.
- * @param p_resv	Pointer to receive the DNS resolver instance.
+ * @param endpt         The SIP endpoint instance.
+ * @param p_resv        Pointer to receive the DNS resolver instance.
  *
- * @return		PJ_SUCCESS on success, or the appropriate error
- *			code.
+ * @return              PJ_SUCCESS on success, or the appropriate error
+ *                      code.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_create_resolver(pjsip_endpoint *endpt,
-						 pj_dns_resolver **p_resv);
+                                                 pj_dns_resolver **p_resv);
 
 /**
  * Set DNS resolver to be used by the SIP resolver. Application can set
@@ -419,15 +418,15 @@ PJ_DECL(pj_status_t) pjsip_endpt_create_resolver(pjsip_endpoint *endpt,
  * temporarily). When DNS resolver is disabled, the endpoint will resolve
  * hostnames with the normal pj_gethostbyname() function.
  *
- * @param endpt		The SIP endpoint instance.
- * @param resv		The resolver instance to be used by the SIP
- *			endpoint.
+ * @param endpt         The SIP endpoint instance.
+ * @param resv          The resolver instance to be used by the SIP
+ *                      endpoint.
  *
- * @return		PJ_SUCCESS on success, or the appropriate error
- *			code.
+ * @return              PJ_SUCCESS on success, or the appropriate error
+ *                      code.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_set_resolver(pjsip_endpoint *endpt,
-					      pj_dns_resolver *resv);
+                                              pj_dns_resolver *resv);
 
 /**
  * Set the DNS external resolver implementation to use in the SIP resolver. 
@@ -437,23 +436,23 @@ PJ_DECL(pj_status_t) pjsip_endpt_set_resolver(pjsip_endpoint *endpt,
  * PJLIB-UTIL DNS resolver if any (e.g: set using #pjsip_endpt_set_resolver()). 
  * Application that needs it, still be able create its own instance. 
  *
- * @param res       The SIP resolver engine.
+ * @param endpt       The SIP resolver engine.
  * @param ext_res   The external resolver implementation callback. This argument
- *		    can be NULL to reset the whole external implementation. 
- *		    However, it is prohibited to reset individual callback.
+ *                  can be NULL to reset the whole external implementation. 
+ *                  However, it is prohibited to reset individual callback.
  * 
- * @return	    PJ_SUCCESS on success, or the appropriate error code.
+ * @return          PJ_SUCCESS on success, or the appropriate error code.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_set_ext_resolver(pjsip_endpoint *endpt,
-						  pjsip_ext_resolver *ext_res);
+                                                  pjsip_ext_resolver *ext_res);
 
 /**
  * Get the DNS resolver being used by the SIP resolver.
  *
- * @param endpt		The SIP endpoint instance.
+ * @param endpt         The SIP endpoint instance.
  *
- * @return		The DNS resolver instance currently being used
- *			by the SIP endpoint.
+ * @return              The DNS resolver instance currently being used
+ *                      by the SIP endpoint.
  */
 PJ_DECL(pj_dns_resolver*) pjsip_endpt_get_resolver(pjsip_endpoint *endpt);
 
@@ -462,33 +461,33 @@ PJ_DECL(pj_dns_resolver*) pjsip_endpt_get_resolver(pjsip_endpoint *endpt);
  * specified in RFC 3263 (Locating SIP Servers). When the resolving operation
  * has completed, the callback will be called.
  *
- * @param endpt	    The endpoint instance.
- * @param pool	    The pool to allocate resolver job.
+ * @param endpt     The endpoint instance.
+ * @param pool      The pool to allocate resolver job.
  * @param target    The target specification to be resolved.
- * @param token	    A user defined token to be passed back to callback function.
- * @param cb	    The callback function.
+ * @param token     A user defined token to be passed back to callback function.
+ * @param cb        The callback function.
  */
 PJ_DECL(void) pjsip_endpt_resolve( pjsip_endpoint *endpt,
-				   pj_pool_t *pool,
-				   pjsip_host_info *target,
-				   void *token,
-				   pjsip_resolver_callback *cb);
+                                   pj_pool_t *pool,
+                                   pjsip_host_info *target,
+                                   void *token,
+                                   pjsip_resolver_callback *cb);
 
 /**
  * Get transport manager instance.
  *
- * @param endpt	    The endpoint.
+ * @param endpt     The endpoint.
  *
- * @return	    Transport manager instance.
+ * @return          Transport manager instance.
  */
 PJ_DECL(pjsip_tpmgr*) pjsip_endpt_get_tpmgr(pjsip_endpoint *endpt);
 
 /**
  * Get ioqueue instance.
  *
- * @param endpt	    The endpoint.
+ * @param endpt     The endpoint.
  *
- * @return	    The ioqueue.
+ * @return          The ioqueue.
  */
 PJ_DECL(pj_ioqueue_t*) pjsip_endpt_get_ioqueue(pjsip_endpoint *endpt);
 
@@ -500,23 +499,23 @@ PJ_DECL(pj_ioqueue_t*) pjsip_endpt_get_ioqueue(pjsip_endpoint *endpt);
  *
  * @see pjsip_tpmgr_acquire_transport
  *
- * @param endpt	    The SIP endpoint instance.
- * @param type	    The type of transport to be acquired.
+ * @param endpt     The SIP endpoint instance.
+ * @param type      The type of transport to be acquired.
  * @param remote    The remote address to send message to.
  * @param addr_len  Length of the remote address.
- * @param sel	    Optional pointer to transport selector instance which is
- *		    used to find explicit transport, if required.
- * @param p_tp	    Pointer to receive the transport instance, if one is found.
+ * @param sel       Optional pointer to transport selector instance which is
+ *                  used to find explicit transport, if required.
+ * @param p_tp      Pointer to receive the transport instance, if one is found.
  *
- * @return	    PJ_SUCCESS on success, or the appropriate error code.
+ * @return          PJ_SUCCESS on success, or the appropriate error code.
  */
 PJ_DECL(pj_status_t) 
 pjsip_endpt_acquire_transport( pjsip_endpoint *endpt,
-			       pjsip_transport_type_e type,
-			       const pj_sockaddr_t *remote,
-			       int addr_len,
-			       const pjsip_tpselector *sel,
-			       pjsip_transport **p_tp);
+                               pjsip_transport_type_e type,
+                               const pj_sockaddr_t *remote,
+                               int addr_len,
+                               const pjsip_tpselector *sel,
+                               pjsip_transport **p_tp);
 
 
 /**
@@ -527,25 +526,25 @@ pjsip_endpt_acquire_transport( pjsip_endpoint *endpt,
  *
  * @see pjsip_tpmgr_acquire_transport
  *
- * @param endpt	    The SIP endpoint instance.
- * @param type	    The type of transport to be acquired.
+ * @param endpt     The SIP endpoint instance.
+ * @param type      The type of transport to be acquired.
  * @param remote    The remote address to send message to.
  * @param addr_len  Length of the remote address.
- * @param sel	    Optional pointer to transport selector instance which is
- *		    used to find explicit transport, if required.
- * @param tdata	    Optional pointer to SIP message data to be sent.
- * @param p_tp	    Pointer to receive the transport instance, if one is found.
+ * @param sel       Optional pointer to transport selector instance which is
+ *                  used to find explicit transport, if required.
+ * @param tdata     Optional pointer to SIP message data to be sent.
+ * @param p_tp      Pointer to receive the transport instance, if one is found.
  *
- * @return	    PJ_SUCCESS on success, or the appropriate error code.
+ * @return          PJ_SUCCESS on success, or the appropriate error code.
  */
 PJ_DECL(pj_status_t) 
 pjsip_endpt_acquire_transport2(pjsip_endpoint *endpt,
-			       pjsip_transport_type_e type,
-			       const pj_sockaddr_t *remote,
-			       int addr_len,
-			       const pjsip_tpselector *sel,
-			       pjsip_tx_data *tdata,
-			       pjsip_transport **p_tp);
+                               pjsip_transport_type_e type,
+                               const pj_sockaddr_t *remote,
+                               int addr_len,
+                               const pjsip_tpselector *sel,
+                               pjsip_tx_data *tdata,
+                               pjsip_transport **p_tp);
 
 
 /*****************************************************************************
@@ -567,82 +566,82 @@ pjsip_endpt_acquire_transport2(pjsip_endpoint *endpt,
 /**
  * Get the value of the specified capability header field.
  *
- * @param endpt	    The endpoint.
- * @param htype	    The header type to be retrieved, which value may be:
- *		    - PJSIP_H_ACCEPT
- *		    - PJSIP_H_ALLOW
- *		    - PJSIP_H_SUPPORTED
- * @param hname	    If htype specifies PJSIP_H_OTHER, then the header name
- *		    must be supplied in this argument. Otherwise the value
- *		    must be set to NULL.
+ * @param endpt     The endpoint.
+ * @param htype     The header type to be retrieved, which value may be:
+ *                  - PJSIP_H_ACCEPT
+ *                  - PJSIP_H_ALLOW
+ *                  - PJSIP_H_SUPPORTED
+ * @param hname     If htype specifies PJSIP_H_OTHER, then the header name
+ *                  must be supplied in this argument. Otherwise the value
+ *                  must be set to NULL.
  *
- * @return	    The appropriate header, or NULL if the header is not
- *		    available.
+ * @return          The appropriate header, or NULL if the header is not
+ *                  available.
  */
 PJ_DECL(const pjsip_hdr*) pjsip_endpt_get_capability( pjsip_endpoint *endpt,
-						      int htype,
-						      const pj_str_t *hname);
+                                                      int htype,
+                                                      const pj_str_t *hname);
 
 
 /**
  * Check if we have the specified capability.
  *
- * @param endpt	    The endpoint.
- * @param htype	    The header type to be retrieved, which value may be:
- *		    - PJSIP_H_ACCEPT
- *		    - PJSIP_H_ALLOW
- *		    - PJSIP_H_SUPPORTED
- * @param hname	    If htype specifies PJSIP_H_OTHER, then the header name
- *		    must be supplied in this argument. Otherwise the value
- *		    must be set to NULL.
- * @param token	    The capability token to check. For example, if \a htype
- *		    is PJSIP_H_ALLOW, then \a token specifies the method
- *		    names; if \a htype is PJSIP_H_SUPPORTED, then \a token
- *		    specifies the extension names such as "100rel".
+ * @param endpt     The endpoint.
+ * @param htype     The header type to be retrieved, which value may be:
+ *                  - PJSIP_H_ACCEPT
+ *                  - PJSIP_H_ALLOW
+ *                  - PJSIP_H_SUPPORTED
+ * @param hname     If htype specifies PJSIP_H_OTHER, then the header name
+ *                  must be supplied in this argument. Otherwise the value
+ *                  must be set to NULL.
+ * @param token     The capability token to check. For example, if \a htype
+ *                  is PJSIP_H_ALLOW, then \a token specifies the method
+ *                  names; if \a htype is PJSIP_H_SUPPORTED, then \a token
+ *                  specifies the extension names such as "100rel".
  *
- * @return	    PJ_TRUE if the specified capability is supported,
- *		    otherwise PJ_FALSE..
+ * @return          PJ_TRUE if the specified capability is supported,
+ *                  otherwise PJ_FALSE..
  */
 PJ_DECL(pj_bool_t) pjsip_endpt_has_capability( pjsip_endpoint *endpt,
-					       int htype,
-					       const pj_str_t *hname,
-					       const pj_str_t *token);
+                                               int htype,
+                                               const pj_str_t *hname,
+                                               const pj_str_t *token);
 
 
 /**
  * Add or register new capabilities as indicated by the tags to the
  * appropriate header fields in the endpoint.
  *
- * @param endpt	    The endpoint.
- * @param mod	    The module which registers the capability.
- * @param htype	    The header type to be set, which value may be:
- *		    - PJSIP_H_ACCEPT
- *		    - PJSIP_H_ALLOW
- *		    - PJSIP_H_SUPPORTED
- * @param hname	    If htype specifies PJSIP_H_OTHER, then the header name
- *		    must be supplied in this argument. Otherwise the value
- *		    must be set to NULL.
- * @param count	    The number of tags in the array. The value must not
- *		    be greater than PJSIP_GENERIC_ARRAY_MAX_COUNT.
- * @param tags	    Array of tags describing the capabilities or extensions
- *		    to be added to the appropriate header.
+ * @param endpt     The endpoint.
+ * @param mod       The module which registers the capability.
+ * @param htype     The header type to be set, which value may be:
+ *                  - PJSIP_H_ACCEPT
+ *                  - PJSIP_H_ALLOW
+ *                  - PJSIP_H_SUPPORTED
+ * @param hname     If htype specifies PJSIP_H_OTHER, then the header name
+ *                  must be supplied in this argument. Otherwise the value
+ *                  must be set to NULL.
+ * @param count     The number of tags in the array. The value must not
+ *                  be greater than PJSIP_GENERIC_ARRAY_MAX_COUNT.
+ * @param tags      Array of tags describing the capabilities or extensions
+ *                  to be added to the appropriate header.
  *
- * @return	    PJ_SUCCESS on success.
+ * @return          PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_add_capability( pjsip_endpoint *endpt,
-						 pjsip_module *mod,
-						 int htype,
-						 const pj_str_t *hname,
-						 unsigned count,
-						 const pj_str_t tags[]);
+                                                 pjsip_module *mod,
+                                                 int htype,
+                                                 const pj_str_t *hname,
+                                                 unsigned count,
+                                                 const pj_str_t tags[]);
 
 /**
  * Get list of additional headers to be put in outgoing request message.
  * Currently only Max-Forwards are defined.
  *
- * @param e	    The endpoint.
+ * @param e         The endpoint.
  *
- * @return	    List of headers.
+ * @return          List of headers.
  */
 PJ_DECL(const pjsip_hdr*) pjsip_endpt_get_request_headers(pjsip_endpoint *e);
 
@@ -651,10 +650,10 @@ PJ_DECL(const pjsip_hdr*) pjsip_endpt_get_request_headers(pjsip_endpoint *e);
  * Dump endpoint status to the log. This will print the status to the log
  * with log level 3.
  *
- * @param endpt		The endpoint.
- * @param detail	If non zero, then it will dump a detailed output.
- *			BEWARE that this option may crash the system because
- *			it tries to access all memory pools.
+ * @param endpt         The endpoint.
+ * @param detail        If non zero, then it will dump a detailed output.
+ *                      BEWARE that this option may crash the system because
+ *                      it tries to access all memory pools.
  */
 PJ_DECL(void) pjsip_endpt_dump( pjsip_endpoint *endpt, pj_bool_t detail );
 
@@ -666,13 +665,13 @@ PJ_DECL(void) pjsip_endpt_dump( pjsip_endpoint *endpt, pj_bool_t detail );
  * from within the callback as such resource may have been released when
  * the callback function is invoked.
  *
- * @param endpt		The SIP endpoint.
- * @param func		The function to be registered.
+ * @param endpt         The SIP endpoint.
+ * @param func          The function to be registered.
  *
- * @return		PJ_SUCCESS on success.
+ * @return              PJ_SUCCESS on success.
  */
 PJ_DECL(pj_status_t) pjsip_endpt_atexit(pjsip_endpoint *endpt,
-					pjsip_endpt_exit_callback func);
+                                        pjsip_endpt_exit_callback func);
 
 
 /**
@@ -684,14 +683,17 @@ PJ_DECL(pj_status_t) pjsip_endpt_atexit(pjsip_endpoint *endpt,
  * Log an error.
  */
 PJ_DECL(void) pjsip_endpt_log_error( pjsip_endpoint *endpt,
-				     const char *sender,
+                                     const char *sender,
                                      pj_status_t error_code,
                                      const char *format,
-                                     ... );
+                                     ... )
+                                     PJ_PRINT_FUNC_DECOR(4);
 
+/** Internal */
 #define PJSIP_ENDPT_LOG_ERROR(expr)   \
             pjsip_endpt_log_error expr
 
+/** Internal */
 #define PJSIP_ENDPT_TRACE(tracing,expr) \
             do {                        \
                 if ((tracing))          \
@@ -701,13 +703,13 @@ PJ_DECL(void) pjsip_endpt_log_error( pjsip_endpoint *endpt,
 /*
  * Internal functions.
  */
-/*
- * Receive transaction events from transactions and put in the event queue
- * to be processed later.
+/**
+ * Internal: receive transaction events from transactions and put in the
+ * event queue to be processed later.
  */
 void pjsip_endpt_send_tsx_event( pjsip_endpoint *endpt, pjsip_event *evt );
 
 PJ_END_DECL
 
-#endif	/* __PJSIP_SIP_ENDPOINT_H__ */
+#endif  /* __PJSIP_SIP_ENDPOINT_H__ */
 
