@@ -62,6 +62,18 @@ struct AccountRegConfig : public PersistentObject
      */
     bool                registerOnAdd;
 
+    /**
+     * Specify whether account modification with Account::modify() should
+     * automatically update registration if necessary, for example if
+     * account credentials change.
+     *
+     * Disable this when immediate registration is not desirable, such as
+     * during IP address change.
+     *
+     * Default: false.
+     */
+    bool                disableRegOnModify;
+
     /**
      * The optional custom SIP headers to be put in the registration
      * request.
@@ -787,6 +799,37 @@ public:
     virtual void writeObject(ContainerNode &node) const PJSUA2_THROW(Error);
 };
 
+/**
+ * This structure contains parameters for Account::sendRequest()
+ */
+struct SendRequestParam
+{
+    /**
+     * Token or arbitrary user data ownd by the application,
+     * which will be passed back in callback Account::onSendRequest().
+     */
+    Token        userData;
+
+    /**
+     * SIP method of the request.
+     */
+    string       method;
+
+    /**
+     * Message body and/or list of headers etc. to be included in
+     * the outgoing request.
+     */
+    SipTxOption  txOption;
+
+public:
+    /**
+     * Default constructor initializes with zero/empty values.
+     */
+    SendRequestParam();
+};
+
+
+
 /**
  * SRTP crypto.
  */
@@ -1713,6 +1756,24 @@ struct OnMwiInfoParam
     SipRxData           rdata;
 };
 
+/**
+ * This structure contains parameters for Account::onSendRequest() callback.
+ */
+struct OnSendRequestParam
+{
+    /**
+     * Token or arbitrary user data owned by the application,
+     * which was passed to Endpoint::sendRquest() function.
+     */
+    Token               userData;
+
+    /**
+     * Transaction event that caused the state change.
+     */
+    SipEvent    e;
+};
+
+
 /**
  * Parameters for presNotify() account method.
  */
@@ -1889,6 +1950,18 @@ public:
      */
     AccountInfo getInfo() const PJSUA2_THROW(Error);
 
+    /**
+     * Send arbitrary requests using the account. Application should only use
+     * this function to create auxiliary requests outside dialog, such as
+     * OPTIONS, and use the call or presence API to create dialog related
+     * requests.
+     *
+     * @param prm.method    SIP method of the request.
+     * @param prm.txOption  Optional message body and/or list of headers to be
+     *                      included in outgoing request.
+     */
+    void sendRequest(const pj::SendRequestParam& prm) PJSUA2_THROW(Error);
+
     /**
      * Update registration or perform unregistration. Application normally
      * only needs to call this function if it wants to manually update the
@@ -2070,6 +2143,15 @@ public:
     virtual void onInstantMessageStatus(OnInstantMessageStatusParam &prm)
     { PJ_UNUSED_ARG(prm); }
 
+    /**
+     * Notify application when a transaction started by Account::sendRequest()
+     * has been completed,i.e. when a response has been received.
+     *
+     * @param prm       Callback parameter.
+     */
+    virtual void onSendRequest(OnSendRequestParam &prm)
+    { PJ_UNUSED_ARG(prm); }
+
     /**
      * Notify application about typing indication.
      *
